// Simulate config options from your production environment by
// customising the .env file in your project's root folder.
if (process.env.NODE_ENV !== 'production') {
    require('dotenv').load();
}

// Require keystone
var keystone = require('keystone');
var mongoose = require('mongoose');

// Override the instance of mongoose ... with 4.0
keystone.set('mongoose', mongoose);

// Initialise Keystone with your project's configuration.
// See http://keystonejs.com/guide/config for available options
// and documentation.

keystone.init({

	'name': 'middleman',
	'brand': 'middleman',
	
	'less': 'public',
	'static': 'public',
	'favicon': 'public/favicon.ico',
	'views': 'templates/views',
	'view engine': 'jade',

	'auto update': true,
	'session': true,
	'session store': 'mongo',
	'auth': true,
	'user model': 'User',
	'cookie secret': '*zC*Hx>]R)ksuQ$:W{`t;-7mmMlOlhVHcO1]Kgn86oWc3/)4."I7Tp$RUu;w+@T;'

});

// Load your project's Models

keystone.import('models');

// Setup common locals for your templates. The following are required for the
// bundled templates and layouts. Any runtime locals (that should be set uniquely
// for each request) should be added to ./routes/middleware.js

keystone.set('locals', {
	_: require('lodash'),
	env: keystone.get('env'),
	utils: keystone.utils,
	editable: keystone.content.editable
});

// Load your project's Routes

keystone.set('routes', require('./routes'));

// Setup common locals for your emails. The following are required by Keystone's
// default email templates, you may remove them if you're using your own.

// Configure the navigation bar in Keystone's Admin UI

keystone.set('nav', {
	'users': 'users'
});

// Start Keystone to connect to your database and initialise the web server

keystone.start();
